iGEM WikiSync
=============

<!-- Badges Start -->

<p align='center'>
    <a href="https://https://pypi.org/project/igem-wikisync/">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/igem-wikisync?style=for-the-badge">
    </a> 
    <a href="https://readthedocs.org/projects/igem-wikisync">
        <img src="https://img.shields.io/readthedocs/igem-wikisync?logo=Read%20The%20Docs&style=for-the-badge" alt="Documentation Status">
    </a> 
    <a href="https://travis-ci.com/igembitsgoa/igem-wikisync">
        <img src="https://img.shields.io/travis/com/igembitsgoa/igem-wikisync?logo=travis&style=for-the-badge" alt="Travis-CI Build Status">
    </a>
    <a href="https://requires.io/github/igembitsgoa/igem-wikisync/requirements/?branch=master">
        <img src="https://img.shields.io/requires/github/igembitsgoa/igem-wikisync?style=for-the-badge" alt="Requirements Status">
    </a>
    <a href="https://coveralls.io/r/igembitsgoa/igem-wikisync">
        <img src="https://img.shields.io/coveralls/github/igembitsgoa/igem-wikisync?logo=coveralls&style=for-the-badge" alt="Coverage Status">
    </a>
    <a href="https://github.com/igembitsgoa/igem-wikisync/">
        <img src="https://img.shields.io/github/commits-since/igembitsgoa/igem-wikisync/v1.1.0-alpha?logo=github&style=for-the-badge" alt="Commits since latest release">
    </a>
    <img src="https://img.shields.io/pypi/l/igem-wikisync?style=for-the-badge" alt="License: MIT">
</p>

<!-- Badges End -->

iGEM WikiSync is an elegant and simple way to upload [iGEM](https://igem.org) Wikis.

WikiSync eliminates the need to manually upload each file, replace each URL and copy paste your source code into a web form. Building and deployment can now be as simple as a `git push`, thanks to [Travis](https://travis-ci.com).

Please head over to our [documentation](https://igem-wikisync.readthedocs.io) to know more about this project and how you can use it to build your wiki faster.

Installation
------------

    pip install igem-wikisync

Collaboration
-------------
Using this software or submitting issues and pull requests can count towards a collaboration for our teams. Please give us a shoutout at [@igem_bits](https://www.instagram.com/igem_bits/) on Instagram if WikiSync has made your iGEM experience easier! For contibuting to this software or discussing further collaborations, please reach out to us at igembitsgoa@gmail.com.